@@ -6,7 +6,7 @@ require Exporter;
 use warnings;
 use strict;
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 use Carp;
 use Convert::Moji qw/make_regex length_one unambiguous/;
@@ -290,7 +290,7 @@ for my $vowel (keys %dan) {
 
 # Added d to the list for ウッド BKB 2010-07-20 23:27:07
 # Added z for "badge" etc.
-# add d for ドッグ
+# Added g for ドッグ etc.
 
 my @takes_sokuon_gyou = qw/s t k p d z g/;
 my @takes_sokuon = (map {@{$gyou{$_}}} @takes_sokuon_gyou);
@@ -490,10 +490,11 @@ sub kana2romaji
     $input =~ s/([カ-ヂツ-ヱヴ])/$siin{$1}$boin{$1}/g;
     $input =~ s/q([aiueo])/x$1/g;
     if ($common) {
-	# Convert kana + small vowel into thingumibob.
-	$input =~ s/([^aiueo])[aiueo]x([aiueo])/$1$2/;
+	# Convert kana + small vowel into thingumibob, if there is a
+	# consonant before.
+	$input =~ s/([^\Waiueo])[aiueo]x([aiueo])/$1$2/;
 	# Convert u + small kana into w + vowel
-	$input =~ s/([aiueo]|\b)ux([iue])/$1w$2/
+	$input =~ s/([aiueo]|\b)ux([iue])/$1w$2/i;
     }
     return $input;
 }
@@ -521,6 +522,9 @@ sub romaji_styles
     }, {
         abbrev    => 'kunrei',
         full_name => 'Kunrei-shiki',
+    }, {
+	abbrev => 'common',
+	full_name => 'common',
     });
     if (! defined ($check)) {
         return (@styles);
